package fr.itsonus.bousoleplussbackend.infrastructure.postgres.models;

import com.fasterxml.jackson.annotation.JsonIgnore;
import fr.itsonus.bousoleplussbackend.domain.quiz.model.QuizResponse;
import jakarta.persistence.Entity;
import jakarta.persistence.GeneratedValue;
import jakarta.persistence.Id;
import jakarta.persistence.JoinColumn;
import jakarta.persistence.ManyToOne;
import jakarta.persistence.OneToOne;
import jakarta.validation.constraints.Max;
import jakarta.validation.constraints.Min;
import lombok.Getter;
import lombok.RequiredArgsConstructor;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.Accessors;
import org.hibernate.Hibernate;
import org.hibernate.validator.constraints.Length;

import java.util.Objects;

@Getter
@Setter
@ToString
@RequiredArgsConstructor
@Accessors(chain = true)
@Entity(name = "response")
public class PostgresQuizResponseDto {

    @Id
    @GeneratedValue
    private Long id;

    @OneToOne
    @JoinColumn(name = "question_id")
    private PostgresQuestionDto question;

    @ManyToOne
    @JoinColumn(name = "quiz_id")
    @JsonIgnore
    private PostgresQuizDto quiz;

    @Min(0)
    @Max(10)
    private Short score;

    @Length(max = 500)
    private String comment;

    public PostgresQuizResponseDto(QuizResponse quizResponse) {
        this.score = quizResponse.score();
        this.comment = quizResponse.comment();
    }

    public QuizResponse toQuizResponse() {
        return new QuizResponse(
                getQuestion().getAxe().getIdentifier(),
                getQuestion().getLabel(),
                getScore(),
                getComment());
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || Hibernate.getClass(this) != Hibernate.getClass(o)) return false;
        PostgresQuizResponseDto response = (PostgresQuizResponseDto) o;
        return id != null && Objects.equals(id, response.id);
    }

    @Override
    public int hashCode() {
        return getClass().hashCode();
    }
}
