// https://nuxt.com/docs/api/configuration/nuxt-config
export default defineNuxtConfig({
  devtools: { enabled: true },

  modules: [
    "@nuxtjs/device",
    "@pinia/nuxt"
  ],

  css: ["~/assets/css/main.scss"],
  ssr: false,

  devServer: {
    port: Number(process.env.PORT) || 3000
  },

  runtimeConfig: {
    public: {
      baseURL: process.env.BACKEND_BASE_URL || "http://localhost:8080"
    }
  },

  components: [
    {
      path: "~/components",
      pathPrefix: false
    }
  ],

  pinia: {
    autoImports: [
      // automatically imports `defineStore`
      "defineStore", // import { defineStore } from 'pinia'
      ["defineStore", "definePiniaStore"] // import { defineStore as definePiniaStore } from 'pinia'
    ]
  },

  vite: {
    css: {
      preprocessorOptions: {
        scss: {
          additionalData:
            '@use "@/assets/css/_color.scss" as *;@use "@/assets/css/_mixin.scss" as *;@use "@/assets/css/_font.scss" as *;@use "@/assets/css/_spacing.scss" as *;'
        }
      }
    }
  },

  compatibilityDate: "2024-07-06"
});
